summaryrefslogtreecommitdiffstats
path: root/chrome/browser/extensions/extension_debugger_api.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/extensions/extension_debugger_api.h')
-rw-r--r--chrome/browser/extensions/extension_debugger_api.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/chrome/browser/extensions/extension_debugger_api.h b/chrome/browser/extensions/extension_debugger_api.h
index 9329476..963eb34 100644
--- a/chrome/browser/extensions/extension_debugger_api.h
+++ b/chrome/browser/extensions/extension_debugger_api.h
@@ -17,7 +17,7 @@
class ExtensionDevToolsClientHost;
-class DebuggerFunction : public SyncExtensionFunction {
+class DebuggerFunction : public AsyncExtensionFunction {
protected:
DebuggerFunction();
virtual ~DebuggerFunction() {}
@@ -47,13 +47,16 @@ class DetachDebuggerFunction : public DebuggerFunction {
DECLARE_EXTENSION_FUNCTION_NAME("experimental.debugger.detach")
};
-// Implements the debugger.postMessage() extension function.
-class PostMessageDebuggerFunction : public DebuggerFunction {
+// Implements the debugger.sendCommand() extension function.
+class SendCommandDebuggerFunction : public DebuggerFunction {
public:
- PostMessageDebuggerFunction();
- ~PostMessageDebuggerFunction();
+ SendCommandDebuggerFunction();
+ ~SendCommandDebuggerFunction();
virtual bool RunImpl();
- DECLARE_EXTENSION_FUNCTION_NAME("experimental.debugger.postMessage")
+
+ void SendResponseBody(Value* body,
+ const std::string& error);
+ DECLARE_EXTENSION_FUNCTION_NAME("experimental.debugger.sendCommand")
};
#endif // CHROME_BROWSER_EXTENSIONS_EXTENSION_DEBUGGER_API_H_